require 'test_helper'
require 'robut/plugin/giphy'

class Robut::Plugin::GiphyTest < Test::Unit::TestCase
  include GiphyTestBase

  def test_replies_with_gif
    @plugin.handle(Time.now, "@john", "@robut giphy american psycho")
    assert_equal ["http://s3.amazonaws.com/giphygifs/media/Ggjwvmqktuvf2/giphy.gif\nPowered by Giphy"], @plugin.reply_to.replies
  end

  def test_replies_without_gif
    @plugin.handle(Time.now, "@john", "@robut giphy hjklxxxx")
    assert_equal ["Sorry, I couldn't find a gif for that."], @plugin.reply_to.replies
  end
  
  def test_doesnt_reply_with_empty
    @plugin.handle(Time.now, "@john", "@robut giphy")
    assert_equal [], @plugin.reply_to.replies
  end
  
  def test_doesnt_reply_with_semicolon
    @plugin.handle(Time.now, "@john", "@robut giphy cat; look at this cat")
    assert_equal [], @plugin.reply_to.replies
  end

  def test_fails_with_invalid_api_key
    Robut::Plugin::Giphy.configure do |config|
      config.api_key = 'your-mom'
      @plugin.handle(Time.now, "@john", "@robut giphy american psycho")
      assert_equal ["Giphy returned an error"], @plugin.reply_to.replies
    end
  end

  protected
  def new_plugin(presence)
    Robut::Plugin::Giphy.new(presence)
  end
end
